==> mailman-2.1.14-1.tgz: mailman-2.1.14-1/doc/mailman-member-es/labels.pl <==
# LaTeX2HTML 2002-2-1 (1.71)
# Associate labels original text with physical files.


$key = q/sec:changeaddress/;
$external_labels{$key} = "$URL/" . q|node22.html|; 
$noresave{$key} = "$nosave";

$key = q/front/;
$external_labels{$key} = "$URL/" . q|node1.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:getack/;
$external_labels{$key} = "$URL/" . q|node24.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:changename/;
$external_labels{$key} = "$URL/" . q|node35.html|; 
$noresave{$key} = "$nosave";

$key = q/contents/;
$external_labels{$key} = "$URL/" . q|node2.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:notopic/;
$external_labels{$key} = "$URL/" . q|node32.html|; 
$noresave{$key} = "$nosave";

$key = q/about/;
$external_labels{$key} = "$URL/" . q|node43.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:nomail/;
$external_labels{$key} = "$URL/" . q|node20.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:sometopic/;
$external_labels{$key} = "$URL/" . q|node31.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:MIME/;
$external_labels{$key} = "$URL/" . q|node28.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:nodupes/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:nolist/;
$external_labels{$key} = "$URL/" . q|node37.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:global/;
$external_labels{$key} = "$URL/" . q|node34.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:email/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:password/;
$external_labels{$key} = "$URL/" . q|node15.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:digest/;
$external_labels{$key} = "$URL/" . q|node27.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:getown/;
$external_labels{$key} = "$URL/" . q|node23.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:getpassword/;
$external_labels{$key} = "$URL/" . q|node16.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:subscribe/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:human/;
$external_labels{$key} = "$URL/" . q|node11.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:posttopic/;
$external_labels{$key} = "$URL/" . q|node30.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:antispam/;
$external_labels{$key} = "$URL/" . q|node40.html|; 
$noresave{$key} = "$nosave";

$key = q/a:commands/;
$external_labels{$key} = "$URL/" . q|node41.html|; 
$noresave{$key} = "$nosave";

$key = q/a:options/;
$external_labels{$key} = "$URL/" . q|node42.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:web/;
$external_labels{$key} = "$URL/" . q|node9.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:unsubscribe/;
$external_labels{$key} = "$URL/" . q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:topics/;
$external_labels{$key} = "$URL/" . q|node29.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2002-2-1 (1.71)
# labels from external_latex_labels array.


$key = q/sec:changeaddress/;
$external_latex_labels{$key} = q|7.3|; 
$noresave{$key} = "$nosave";

$key = q/sec:getack/;
$external_latex_labels{$key} = q|7.5|; 
$noresave{$key} = "$nosave";

$key = q/sec:changename/;
$external_latex_labels{$key} = q|10.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:notopic/;
$external_latex_labels{$key} = q|9.3|; 
$noresave{$key} = "$nosave";

$key = q/sec:nomail/;
$external_latex_labels{$key} = q|7.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:sometopic/;
$external_latex_labels{$key} = q|9.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:MIME/;
$external_latex_labels{$key} = q|8.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:nodupes/;
$external_latex_labels{$key} = q|7.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:nolist/;
$external_latex_labels{$key} = q|10.4|; 
$noresave{$key} = "$nosave";

$key = q/sec:global/;
$external_latex_labels{$key} = q|10.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:email/;
$external_latex_labels{$key} = q|3.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:password/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/sec:digest/;
$external_latex_labels{$key} = q|8.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:getown/;
$external_latex_labels{$key} = q|7.4|; 
$noresave{$key} = "$nosave";

$key = q/sec:getpassword/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:subscribe/;
$external_latex_labels{$key} = q|5.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:posttopic/;
$external_latex_labels{$key} = q|9.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:human/;
$external_latex_labels{$key} = q|4|; 
$noresave{$key} = "$nosave";

$key = q/sec:antispam/;
$external_latex_labels{$key} = q|11.2|; 
$noresave{$key} = "$nosave";

$key = q/a:commands/;
$external_latex_labels{$key} = q|A|; 
$noresave{$key} = "$nosave";

$key = q/a:options/;
$external_latex_labels{$key} = q|B|; 
$noresave{$key} = "$nosave";

$key = q/sec:topics/;
$external_latex_labels{$key} = q|9|; 
$noresave{$key} = "$nosave";

$key = q/sec:web/;
$external_latex_labels{$key} = q|3.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:unsubscribe/;
$external_latex_labels{$key} = q|5.2|; 
$noresave{$key} = "$nosave";

1;

==> mailman-2.1.19rc3.tgz: mailman-2.1.19rc3/doc/mailman-member-es/labels.pl <==
# LaTeX2HTML 2008 (1.71)
# Associate labels original text with physical files.


$key = q/front/;
$external_labels{$key} = "$URL/" . q|node1.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:subscribe/;
$external_labels{$key} = "$URL/" . q|node13.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:human/;
$external_labels{$key} = "$URL/" . q|node11.html|; 
$noresave{$key} = "$nosave";

$key = q/about/;
$external_labels{$key} = "$URL/" . q|node43.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:changename/;
$external_labels{$key} = "$URL/" . q|node35.html|; 
$noresave{$key} = "$nosave";

$key = q/a:options/;
$external_labels{$key} = "$URL/" . q|node42.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:posttopic/;
$external_labels{$key} = "$URL/" . q|node30.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:unsubscribe/;
$external_labels{$key} = "$URL/" . q|node14.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:nolist/;
$external_labels{$key} = "$URL/" . q|node37.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:getown/;
$external_labels{$key} = "$URL/" . q|node23.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:nodupes/;
$external_labels{$key} = "$URL/" . q|node21.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:MIME/;
$external_labels{$key} = "$URL/" . q|node28.html|; 
$noresave{$key} = "$nosave";

$key = q/a:commands/;
$external_labels{$key} = "$URL/" . q|node41.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:sometopic/;
$external_labels{$key} = "$URL/" . q|node31.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:digest/;
$external_labels{$key} = "$URL/" . q|node27.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:getpassword/;
$external_labels{$key} = "$URL/" . q|node16.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:topics/;
$external_labels{$key} = "$URL/" . q|node29.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:notopic/;
$external_labels{$key} = "$URL/" . q|node32.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:nomail/;
$external_labels{$key} = "$URL/" . q|node20.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:changeaddress/;
$external_labels{$key} = "$URL/" . q|node22.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:antispam/;
$external_labels{$key} = "$URL/" . q|node40.html|; 
$noresave{$key} = "$nosave";

$key = q/contents/;
$external_labels{$key} = "$URL/" . q|node2.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:web/;
$external_labels{$key} = "$URL/" . q|node9.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:getack/;
$external_labels{$key} = "$URL/" . q|node24.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:global/;
$external_labels{$key} = "$URL/" . q|node34.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:email/;
$external_labels{$key} = "$URL/" . q|node10.html|; 
$noresave{$key} = "$nosave";

$key = q/sec:password/;
$external_labels{$key} = "$URL/" . q|node15.html|; 
$noresave{$key} = "$nosave";

1;


# LaTeX2HTML 2008 (1.71)
# labels from external_latex_labels array.


$key = q/sec:subscribe/;
$external_latex_labels{$key} = q|5.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:posttopic/;
$external_latex_labels{$key} = q|9.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:changename/;
$external_latex_labels{$key} = q|10.2|; 
$noresave{$key} = "$nosave";

$key = q/a:options/;
$external_latex_labels{$key} = q|B|; 
$noresave{$key} = "$nosave";

$key = q/sec:human/;
$external_latex_labels{$key} = q|4|; 
$noresave{$key} = "$nosave";

$key = q/sec:nodupes/;
$external_latex_labels{$key} = q|7.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:MIME/;
$external_latex_labels{$key} = q|8.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:nolist/;
$external_latex_labels{$key} = q|10.4|; 
$noresave{$key} = "$nosave";

$key = q/sec:getown/;
$external_latex_labels{$key} = q|7.4|; 
$noresave{$key} = "$nosave";

$key = q/sec:unsubscribe/;
$external_latex_labels{$key} = q|5.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:digest/;
$external_latex_labels{$key} = q|8.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:sometopic/;
$external_latex_labels{$key} = q|9.2|; 
$noresave{$key} = "$nosave";

$key = q/a:commands/;
$external_latex_labels{$key} = q|A|; 
$noresave{$key} = "$nosave";

$key = q/sec:topics/;
$external_latex_labels{$key} = q|9|; 
$noresave{$key} = "$nosave";

$key = q/sec:getpassword/;
$external_latex_labels{$key} = q|6.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:changeaddress/;
$external_latex_labels{$key} = q|7.3|; 
$noresave{$key} = "$nosave";

$key = q/sec:notopic/;
$external_latex_labels{$key} = q|9.3|; 
$noresave{$key} = "$nosave";

$key = q/sec:nomail/;
$external_latex_labels{$key} = q|7.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:web/;
$external_latex_labels{$key} = q|3.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:antispam/;
$external_latex_labels{$key} = q|11.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:email/;
$external_latex_labels{$key} = q|3.2|; 
$noresave{$key} = "$nosave";

$key = q/sec:password/;
$external_latex_labels{$key} = q|6|; 
$noresave{$key} = "$nosave";

$key = q/sec:global/;
$external_latex_labels{$key} = q|10.1|; 
$noresave{$key} = "$nosave";

$key = q/sec:getack/;
$external_latex_labels{$key} = q|7.5|; 
$noresave{$key} = "$nosave";

1;
